@@ -6,7 +6,6 @@ use base qw(Module::Build);
 use File::Copy qw(copy);
 use File::Path qw(mkpath);
 use File::Basename qw(basename);
-use Alien::Prototype::Carousel;
 
 sub ACTION_code {
     my $self = shift;
@@ -52,7 +51,7 @@ sub install_carousel {
     return if (-d $self->carousel_target_dir());
 
     my $dst = $self->carousel_target_dir();
-    mkpath( [$dst] ) || die "unable to create '$dst'; $!";
+    mkpath( $dst ) || die "unable to create '$dst'; $!";
 
     print "Installing Carousel component...\n";
     foreach my $file ($self->carousel_files()) {
